.. module:: cobyqa.utils

Utilities
=========

This module implements utilities for COBYQA.

.. currentmodule:: cobyqa.utils

.. autosummary::
    :toctree: generated/

    MaxEvalError
    TargetSuccess
    CallbackSuccess
    FeasibleSuccess
    get_arrays_tol
    exact_1d_array
    show_versions
